﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 캔들 시리즈
        /// </summary>
        private Candle candle;

        /// <summary>
        /// 라인 시리즈
        /// </summary>
        private Line line;

        /// <summary>
        /// SAR 함수
        /// </summary>
        private SARFunction sarFunction;

        /// <summary>
        /// 설정 여부
        /// </summary>
        private bool setting = true;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 캔들 시리즈를 생성한다.

            this.candle = new Candle();

            this.candle.Title = "Data";
            this.candle.Color = Color.FromArgb(200, 230, 90);

            #endregion
            #region SAR 함수를 생성한다.

            this.sarFunction = new SARFunction();

            this.sarFunction.AccelerationFactor = 0.019999999552965164;
            this.sarFunction.MaxStep            = 0.30000001192092896;

            #endregion
            #region 라인 시리즈를 생성한다.

            this.line = new Line();

            this.line.Title           = "SAR";
            this.line.Brush.Color     = Color.FromArgb(90, 150, 220);
            this.line.Pointer.Style   = PointerStyles.Rectangle;
            this.line.Pointer.Visible = true;
            this.line.DataSource      = this.candle;
            this.line.Function        = this.sarFunction;

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Series.Add(this.candle);
            this.tChart.Series.Add(this.line);

            #endregion

            this.candle.FillSampleValues(10);

            Load                                       += Form_Load;
            this.accelerationFactorTextBox.TextChanged += accelerationFactorTextBox_TextChanged;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            this.accelerationFactorTextBox.Text = this.sarFunction.AccelerationFactor.ToString("0.00");

            this.setting = false;
        }

        #endregion
        #region Acceleration factor 텍스트 박스 텍스트 변경시 처리하기 - accelerationFactorTextBox_TextChanged(sender, e)

        /// <summary>
        /// Acceleration factor 텍스트 박스 텍스트 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void accelerationFactorTextBox_TextChanged(object sender, EventArgs e)
        {
            if(!this.setting)
            {
                this.sarFunction.AccelerationFactor = Convert.ToDouble(this.accelerationFactorTextBox.Text);
            }
        }

        #endregion
    }
}